import { Component, OnInit } from '@angular/core';
import { FormGroup, FormControl, Validators, FormArray, AbstractControl, ValidationErrors } from '@angular/forms';
import ContactForm from '../models/ContactForm';

@Component({
  selector: 'app-reactive-contact-form',
  templateUrl: './reactive-contact-form.component.html',
  styleUrls: ['./reactive-contact-form.component.scss']
})
export class ReactiveContactFormComponent implements OnInit {

  formData = new ContactForm();

  form: FormGroup;

  constructor() { }

  ngOnInit() {
    this.form = new FormGroup({
      topic: new FormControl('my topic', Validators.required),
      message: new FormControl('my message'),
      name: new FormControl('my name', [Validators.required, Validators.minLength(4)]),
      email: new FormControl(null, [Validators.required, Validators.email]),
      hobbies: new FormArray([new FormControl(), new FormControl()], this.hobbiesValidator)
    });

    this.form.valueChanges.subscribe(value => {
      console.log('input value changed ', value);
    });

    this.form.get('name').valueChanges.subscribe(value => {
      console.log('name input changed ', value);
    });

    this.form.statusChanges.subscribe(value => {
      console.log('form status changed ', value);
    });
  }

  onSubmit() {
    this.formData.topic = this.form.value.topic;
    // this.formData.topic = this.form.get('topic').value;
    this.formData.message = this.form.value.message;
    this.formData.personName = this.form.value.name;
    this.formData.email = this.form.value.email;
    console.log(this.formData);
  }

  onReset() {
    this.form.reset({
      topic: 'my Topic after reset',
      message: 'my message after reset'
    });
  }

  addHobby() {
    const controls = this.form.get('hobbies') as FormArray;
    controls.push(new FormControl());
  }

  hobbiesValidator(control: AbstractControl): ValidationErrors {
    const array = control.value as Array<string>;
      return { forbiddenHobby: array.length > 0 && array.includes('football')};
  }

}
